#
# spec file for package python-setuptools_scm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with test
Name:           python-setuptools_scm
Version:        2.0.0
Release:        4.3.1
Summary:        Manage your versions by scm tags
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/pypa/setuptools_scm
Source:         https://files.pythonhosted.org/packages/source/s/setuptools_scm/setuptools_scm-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
BuildArch:      noarch
%if %{with test}
# Testing requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  git
BuildRequires:  mercurial
%endif
%if 0%{?suse_version} >= 1000 || 0%{?fedora_version} >= 24
Recommends:     git
Recommends:     mecurial
%endif
%python_subpackages

%description
The setuptools_scm package handles managing your python package versions
in scm metadata. It also handles file finders for the supperted scm's.

%prep
%setup -q -n setuptools_scm-%{version}

%build
%python_build

%install
%python_install

%if %{with test}
%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_bin_suffix}
%endif

%files %{python_files}
%doc LICENSE README.rst CHANGELOG.rst
%{python_sitelib}/*

%changelog
* Mon Sep 24 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-12 (fate#323875, bsc#1054413)
* Thu Apr 12 2018 arun@gmx.de
- update to version 2.0.0:
  * fix #237 - correct imports in code examples
  * improve mercurial commit detection (thanks Aaron)
  * breaking change: remove support for setuptools before parsed
    versions
  * reintroduce manifest as the travis deploy cant use the file finder
  * reconfigure flake8 for future compatibility with black
  * introduce support for branch name in version metadata and support
    a opt-in simplified semver version scheme
* Fri Mar 23 2018 arun@gmx.de
- update to version 1.17.0:
  * fix regression in git support - use a function to ensure it works
    in egg isntalled mode
  * actually fail if file finding fails in order to see broken setups
    instead of generating broken dists (thanks Mehdi ABAAKOUK for both)
- changes from version 1.16.2:
  * fix regression in handling git export ignores (thanks Mehdi
    ABAAKOUK)
- changes from version 1.16.1:
  * fix regression in support for old setuptools versions (thanks
    Marco Clemencic)
- changes from version 1.16.0:
  * drop support for eol python versions
  * #214 - fix missuse in surogate-escape api
  * add the node-and-timestamp local version sheme
  * respect git export ignores
  * avoid shlex.split on windows
  * fix #218 - better handling of mercurial edge-cases with tag
    commits being considered as the tagged commit
  * fix #223 - remove the dependency on the interal SetupttoolsVersion
    as it was removed after long-standing deprecation
* Wed Mar  7 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Recommends only for SUSE
* Sun Jan 28 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.15.7:
  * Fix #174 with #207: Re-use samefile backport as developed in
    jaraco.windows, and only use the backport where samefile is not
    available.
* Sun Sep 24 2017 arun@gmx.de
- specfile:
  * removed no-generic-python.patch, included upstream
- update to version 1.15.6:
  * fix #174 by normalizing windows path using windows apis
- changes from version 1.15.6:
  * fix #171 by unpinning the py version to allow a fixed one to get
    installed
- changes from version 1.15.5:
  * fix #167 by correctly respecting preformatted version metadata
    from PKG-INFO/EGG-INFO
- changes from version 1.15.4:
  * fix issue #164: iterate all found entry points to avoid erros when
    pip remakes egg-info
  * enhance self-use to enable pip install from github again
- changes from version 1.15.3:
  * bring back correctly getting our version in the own sdist,
    finalizes #114
  * fix issue #150: strip local components of tags
- changes from version 1.15.2:
  * fix issue #128: return None when a scm specific parse fails in a
    worktree to ease parse reuse
- changes from version 1.15.1:
  * fix issue #126: the local part of any tags is discarded when
    guessing new versions
  * minor performance optimization by doing fewer git calls in the
    usual cases
* Mon Jun 26 2017 jmatejek@suse.com
- also do not buildrequire mercurial unless specified
- bcond_with test to run the test suite
* Wed May 17 2017 dimstar@opensuse.org
- Do not buildrequire git: having git in the build root causes a
  build cycle over curl -> nghttp2 -> python-setuptoos_scm -> git.
- Do not run the tests relying on git's presence.
* Fri Mar  3 2017 jmatejek@suse.com
- fix singlespec build
- no-generic-python.patch - run tests with the right python executable
  to prevent stray pyc files where they don't belong
* Thu Mar  2 2017 tbechtold@suse.com
- Fix Source url
* Thu Mar  2 2017 tbechtold@suse.com
- Fix python_module macro definition
* Wed Jan 18 2017 michael@stroeder.com
- updated source project URL (now github)
- source link without hash
* Sat Jan 14 2017 hpj@urpla.net
- Update to v1.15.0
  - more sophisticated ignoring of mercurial tag commits when considering
    distance in commits (thanks Petre Mierlutiu)
  - fix issue #114: stop trying to be smart for the sdist and ensure its always
    correctly usign itself
  - update trove classifiers
  - fix issue #84: document using the installed package metadata for sphinx
  - fix issue #81: fail more gracious when git/hg are missing
  - address issue #93: provide an experimental api to customize behaviour on
    shallow git repos a custom parse function may pick pre parse actions to do
    when using git
- Update to v1.14.1
  - fix #109: when detecting a dirty git workdir
  - don't consider untracked file (this was a regression due to #86 in v1.13.1)
  - consider the distance 0 when the git node is unknown (happens when you
    haven't commited anything)
- Update to v1.14.0
  - publish bdist_egg for python 2.6, 2.7 and 3.3-3.5
  - fix issue #107 - dont use node if it is None
- Update to v1.13.1
  - fix issue #86 - detect dirty git workdir without tags
- Update to v1.13.0
  - fix regression caused by the fix of #101 * assert types for version dumping
  * strictly pass all versions trough parsed version metadata
- Update to v1.12.0
  - fix issue #97 - add support for mercurial plugins
  - fix issue #101 - write version cache even for pretend version (thanks
    anarcat for reporting and fixing)
* Tue Dec  6 2016 buschmann23@opensuse.org
- changes source file URL
* Mon Dec  5 2016 buschmann23@opensuse.org
- Update to 1.11.1:
  * fix issue #88 - better docs for sphinx usage (thanks Jason)
  * fix issue #89 - use normpath to deal with windows (thanks Te-jé
    Rodgers for reporting and fixing)
- Update to 1.11.0:
  * always run tag_to_version so in order to handle prefixes on old
    setuptools (thanks to Brian May)
  * drop support for python 3.2
  * extend the error message on missing scm metadata (thanks Markus
    Unterwaditzer)
  * fix bug when using callable version_scheme (thanks Esben Haabendal)
* Tue Jan 12 2016 michael@stroeder.com
- Update to 1.10.1:
  v1.10.1
  * fix issue #73 - in hg pre commit merge, consider parent1 instead of failing
  v1.10.0
  * add support for overriding the version number via the
  environment variable SETUPTOOLS_SCM_PRETEND_VERSION
  * fix isssue #63 by adding the --match parameter to the git describe call
  and prepare the possibility of passing more options to scm backends
  * fix issue #70 and #71 by introducing the parse keyword
  to specify custom scm parsing, its an expert feature,
  use with caution
  this change also introduces the setuptools_scm.parse_scm_fallback
  entrypoint which can be used to register custom archive fallbacks
  v1.9.0
  * Add :code:`relative_to` parameter to :code:`get_version` function;
  fixes #44 per #45.
* Mon Nov  9 2015 mcihar@suse.cz
- Update to 1.8.0:
  * fix issue with setuptools wrong version warnings being printed to standard
    out. User is informed now by distutils-warnings.
  * restructure root finding, we now reliably ignore outer scm
    and prefer PKG-INFO over scm, fixes #43 and #45
  * correct the url to github
    thanks David Szotten
  * enhance scm not found errors with a note on git tarballs
    thanks Markus
  * add support for :code:`write_to_template`
* Wed Aug 12 2015 toddrme2178@gmail.com
- Initial version
